@@ -1,4 +1,4 @@
-import timeit
+import time
 from jinja2 import Template
 
 from ..messages.Measure import Measure
@@ -10,15 +10,14 @@ class MeasureCollector:
         self.name = name
 
     def restart(self):
-        # self.measures = {}
         return self
 
-    def start_measure(self, key):
-        self.measures.update({key: Measure(timeit.timeit())})
+    def start_measure(self, key, value=None):
+        self.measures.update({key: Measure(value or time.time())})
         return self
 
     def stop_measure(self, key):
-        self.measures.get(key).stop_measure(timeit.timeit())
+        self.measures.get(key).stop_measure(time.time())
         return self
 
     def collect(self):
@@ -34,7 +33,7 @@ class MeasureCollector:
             )
         template = Template(self.html())
         return {
-            "description": "Time Measurements in s",
+            "description": "Time Measurements in seconds",
             "count": len(collection),
             "data": collection,
             "html": template.render({"data": collection}),
@@ -43,7 +42,7 @@ class MeasureCollector:
     def html(self):
         return """
         {% for object in data %}
-            <div class="flex flex-1 alternate-gray alternate-white">
+            <div class="flex flex-1 alternate-gray alternate-white p-4">
                 <div class="pr-4">{{ object.name }}</div>
                 <div>{{ object.diff }}</div>
             </div>
